function [ ] = plotAuction( obj, write )
% plotAuction  Plot tariffs for each bidder in auction
%
% INPUT :
%  obj          auctionData object
%  write        dummy for whether to write the bid object to a file
%
% OUTPUT :
%               Writes plot to file


%% Formatting options
textProp = {'fontsize'    , 24, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 14, ...
            'FontName'    , textProp{4}};
          
lineSpecs = {'k-','k:','k--',...
             'b-','b:','b--',...
             'r-','r:','r--',...
             'y-','y:','y--',...
             'g-','g:','g--',...
             'c-','c:','c--'};

%% Lines to plot
%    Capacity charge, capacity + non-escalable energy, capacity +
%    non-escalable energy + escalable energy
years = [1:26]';
    
%% Plot each bid in the auction  
nbids = length(obj.bid_keys);
ymax  = 0;

for i = 1:nbids
    bid_path = obj.bids.(obj.bid_keys{i}).annual;
    ymax = max( ymax, max(bid_path) );
    plot(years,bid_path,lineSpecs{i},'LineWidth',2);  
    if i == 1
        hold on;
    end
end
xlim([0 30]);
ylim([0 ceil(1.05*ymax)]);
% ylim([0 10]);

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'YTick'       , [ 0: 2: ceil(1.05*ymax) ]  , ...
         'Box'         , 'off'              , ...
         'LineWidth'   , 1.5                );  
     
%               'YTick'       , [0:2:10], ...


     
% Axis labels
title('Tariff Bid by Year');
xlabel('Year of contract',textProp{:})
units = ' (INR per kWh)';
ylabel(['Nominal tariff',units],textProp{:})

% Label levelised tariffs
for i = 1:nbids
    text(27,obj.bids.(obj.bid_keys{i}).annual(end),...
         sprintf('L%2g : %2.1f',obj.rank(i),obj.lt(i)),labProp{:});
end
hold off;

% List bids that were plotted
for i = 1:nbids
    key = obj.bid_keys{i};
    fprintf(1,'Bid: %s (L%2.0f)\n',obj.bids.(key).bid_id,obj.rank(i));
    fprintf(1,'\tCapacity charge (first year): %5.3f\n',...
        obj.bids.(key).raw.NON_ESCALABLECAPACITYCHARGE_RS_KWH_(1));
    fprintf(1,'\tLevelised tariff:             %5.3f\n',obj.bids.(key).lt);
end 

%% Export figure to file
if write
    file = sprintf('fig_bid_parts_%s_%s_%s.pdf','nominal','INR',obj.auction_id);
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end