function [ ] = plotBid( obj, write )
% plotLevelisedTariff  Plot contribution of future years to levelised bid
%
% INPUT :
%  obj          powerBidData object
%  write        dummy for whether to write the bid object to a file
%
% OUTPUT :
%               Writes plot to file

%% Formatting options
% textProp = {'fontsize'    , 32, ...
%             'FontName'    , 'Times New Roman'};
% labProp  = {'fontsize'    , 24, ...
%             'FontName'    , textProp{4}};
        
textProp = {'fontsize'    , 24, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 18, ...
            'FontName'    , textProp{4}};

%% Options for plot type

% parts     Whether to plot bid components or aggregate
% currency  INR or USD
% present   Whether to plot present value or nominal value
 
% if present
%     pv = t .* repmat(delta,1,size(t,2));
% else
%     pv = t;
% end
% 
% % Adjust for exchange rate from INR/kWh to cents/kWh
% if inrPerUsd ~= 1
%     pv = pv ./ inrPerUsd * 100;
% end
        
        
%% Lines to plot
%    Capacity charge, capacity + non-escalable energy, capacity +
%    non-escalable energy + escalable energy
years = [1:26]';
bid   = cumsum(obj.parts,2);
        
%% Plot supply, demand and the clearing price
plot(years,bid(:,1),'b--','LineWidth',2);  hold on;
plot(years,bid(:,2),'r:', 'LineWidth',2);
plot(years,bid(:,3),'k-', 'LineWidth',2);

ymax = max( bid(:) );
xlim([0 30]);
% ylim([0 ceil(1.05*ymax)]);
ylim([0 10]);

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'YTick'      , 0:2:10                , ...
         'LineWidth'   , 1.5                );  
     
% Axis labels
xlabel('Year of contract',textProp{:})
units = ' (INR per kWh)';
ylabel(['Nominal tariff',units],textProp{:})

% if inrPerUsd == 1
%     units = ' (INR/kWh)';
% else
%     units = ' (cents/kWh)';
% end
% if present
%     ylabel(['Present value of tariff',units],textProp{:})
% else
%     ylabel(['Future tariff',units],textProp{:})
% end

title(sprintf('Tariff Bid by Year'));

% Text labels
ypos = bid(end,:)';
type = {'Capacity','Not indexed','Total'};
for l = 1:length(ypos)
    text(27,ypos(l),sprintf('%s',type{l}), labProp{:});
end
hold off;

%% Export figure to file
if write
    file = sprintf('fig_bid_parts_%s_%s_%s.pdf','nominal','INR',obj.bid_id);
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end