function [ ] = plotResidualScoreDistribution( obj, write )
% plotScoreDistribution  Plot distribution of scores
%
% INPUT :
%  obj          scoreModel object
%  bids         table of bid data
%  write        dummy for whether to write the bid object to a file
%
% OUTPUT :
%               Writes plot to file

%% Formatting options
textProp = {'fontsize'    , 32, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 24, ...
            'FontName'    , textProp{4}};
        
%% Data to plot
S     = obj.bids.LevelisedTariff;
resid = (log(S) - obj.mu_auction_pred)./obj.sig_auction_pred;

mu_bar  = mean(obj.mu_auction_pred);
sig_bar = mean(obj.sig_auction_pred);
resid_scaled = exp( resid*sig_bar + mu_bar );

maxBinEdge = 2*ceil(max(resid_scaled)/2);

% Log-normal distribution as fit
Sgrid  = linspace(1,7);
fSgrid = lognpdf(Sgrid,mu_bar,sig_bar); 


%% Plot supply, demand and the clearing price
histogram(resid_scaled,'BinEdges',[0:0.5:maxBinEdge],...
          'FaceColor','blue','Normalization','pdf');
hold on;

ylim([0 1.0]);
plot(Sgrid,fSgrid,'r-','LineWidth',2.5);

fprintf(1,'Variance of residual score distribution: %4.2f\n',var(resid_scaled));

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'XTick'       , 0:1:8              , ...
         'YTick'       , 0:0.2:1.0          , ...
         'LineWidth'   , 1.5                );  
     
% Axis labels
xlabel('Residual Score (INR/kWh)',textProp{:})
ylabel('Density',textProp{:})

% title(sprintf('Annual Tariff Offered by Year'));

% Text labels
% ypos = bid(end,:)';
% type = {'Capacity','Not indexed','Total'};
% for l = 1:length(ypos)
%     text(27,ypos(l),sprintf('%s',type{l}), labProp{:});
% end
hold off;

%% Export figure to file
if write
    file = sprintf('fig_score_distribution_residual.pdf');
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end