function [ ] = plotScoreDistribution( obj, write )
% plotScoreDistribution  Plot distribution of scores
%
% INPUT :
%  obj          scoreModel object
%  write        dummy for whether to write the bid object to a file
%
% OUTPUT :
%               Writes plot to file

%% Formatting options
textProp = {'fontsize'    , 32, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 24, ...
            'FontName'    , textProp{4}};
        
%% Data to plot
S = obj.bids.LevelisedTariff;
maxBinEdge = ceil(max(S));

%% Plot supply, demand and the clearing price
histogram(S,'BinEdges',[0:0.5:maxBinEdge],...
          'FaceColor','blue','Normalization','pdf');
ylim([0 1.0]);
hold on;

fprintf(1,'Variance of score distribution: %4.2f\n',var(S));

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'XTick'       , 0:1:maxBinEdge     , ...
         'YTick'       , 0:0.2:1.0         , ...
         'LineWidth'   , 2                );  
     
% Axis labels
xlabel('Score (INR/kWh)',textProp{:})
ylabel('Density',textProp{:})

% title(sprintf('Annual Tariff Offered by Year'));

% Text labels
% ypos = bid(end,:)';
% type = {'Capacity','Not indexed','Total'};
% for l = 1:length(ypos)
%     text(27,ypos(l),sprintf('%s',type{l}), labProp{:});
% end
hold off;

%% Export figure to file
if write
    file = sprintf('fig_score_distribution.pdf');
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end