function [ ] = plot2d( obj, file )
%plot Plot 2-D type distribution from type model object
%   
% INPUT :
%  obj         type model object with estimates of 2-D types
%
% OUTPUT :
%              Writes plot to file
if nargin < 2
    file = 0;
end

%% Formatting options
textProp = {'fontsize'    , 20, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 18, ...
            'FontName'    , textProp{4}};
        
        
%% Data to plot
theta = [ obj.bids.h obj.bids.Delta ];
theta = theta( ~isnan(theta(:,1)), : )';

%% Kernel density estimation on a grid

% Bandwidths and kernel
h_h = 1000;
h_D = 0.2;
% K   = @(u) 0.75*(1-u.^2) .* (abs(u) <= 1); % Epanechnikov kernel
K   = @(u) 1/sqrt(2*pi)*exp(-u.^2/2);      % Normal kernel
n   = size(theta,2);

% Range over which to plot density
h_range = [ 0:250:35000 ]';
D_range = [ 0:0.1:5 ]';
[ h0, D0 ] = ndgrid(h_range,D_range);
h0v = h0(:);
D0v = D0(:);
P = length(h0v);

% Calculate density for every point in grid
K_pi = 1/h_h*K( (theta(ones(P,1),:)-h0v(:,ones(1,n)))/h_h ) ...
       .* 1/h_D .* K( (theta(2*ones(P,1),:)-D0v(:,ones(n,1)))/h_D ); 
ftheta0 = 1/n * sum( K_pi, 2);
ftheta0 = reshape(ftheta0,size(h0,1),[]);
       
%% Plot supply, demand and the clearing price
surf(h0,D0,ftheta0);
hold on;
view(157,27);

xlim([0 25000]);
ylim([0 2]);

% Figure formatting
c = gray;
lightgray = c(33:end,:);
colormap(lightgray);

% c = autumn;
% lightautumn = c(6:end,:);
% colormap(lightautumn);

set(gcf, 'Color'       , 'w' );
set(gcf, 'units', 'points', 'position', [200,200,800,800] );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'LineWidth'   , 1.5                );  
     
% Axis labels
xlabel('Heat rate $h_i$ (btu/kWh)',textProp{:},'Interpreter','latex')
ylabel('Bonus $\Delta_i$ (INR/kWh)',textProp{:},'Interpreter','latex')
% title('Joint Distribution of Bidder Types','Interpreter','latex');

hold off;

%% Export figure to file
if file
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end
