function [ ] = plotBidFunction( obj, bid_idx, hi, file )
%plot Plot 1-D type distribution for heat rate from type model object
%   
% INPUT :
%  obj         type model object with estimates of types
%  bid_id      bid_id of auction for which to calculate optimal bid
%  hi          vector of heat rates at which to calculate optimal bid
%  file        name of output file
%
% OUTPUT :
%              Writes plot to file
if nargin < 4
    file = 0;
end

%% Formatting options
textProp = {'fontsize'    , 24, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 18, ...
            'FontName'    , textProp{4}};
        
%% Data to plot
[ bc_i, ci ] = obj.optimalBid( bid_idx, hi );


%% Plot bid function
plot(ci,bc_i,'k-' ,'LineWidth',2);  
hold on;
plot(ci,ci,'k:' ,'LineWidth',1);  

% xlim([floor(min(ci)) ceil(max(ci))]);
% ylim([floor(min(ci)) ceil(max(ci))]);

xlim([2 8]);
ylim([2 8]);

% Figure formatting
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'LineWidth'   , 1.5                );  
     
% Axis labels
xlabel('Cost (INR/kWh)',textProp{:},'Interpreter','latex')
ylabel('Optimal bid (INR/kWh)',textProp{:},'Interpreter','latex')
hold off;

%% Export figure to file
if file
    fprintf(1,'Writing %s to file ...',file);
    export_fig(file,'-painters','-m2');
    fprintf(1,' complete.\n');
end

end
