function [ output_args ] = summarize( obj )
%summarize Summarize output of type model object
%   method to apply to an estimated typeModel to examine estimated types

% Conditional means of types
fprintf(1,'Mean types across years\n');
gs = grpstats( obj.bids,'auction_year', {'mean'}, ...
               'datavars', {'k','h','Delta'});
display(gs);

fprintf(1,'Mean types across fuel source\n');
gs = grpstats( obj.bids,'source', {'mean'}, ...
               'datavars', {'k','h','Delta'});
display(gs);

fprintf(1,'Mean types across auctions\n');
gs = grpstats( obj.bids,'auction_id_provisional', {'mean'}, ...
               'datavars', {'k','h','Delta'});
display(gs);

% Percentiles of type distribution across years

% For heat
auction_years = unique(obj.bids.auction_year);
pctiles = [ 5 10 25 50 75 90 95 ];
heat_pctiles = zeros(length(auction_years),length(pctiles));
for i = 1:length(auction_years)
    heat_pctiles(i,:) = prctile(obj.bids.h(obj.bids.auction_year==...
        auction_years(i)),pctiles);
end

fprintf(1,'Percentiles of heat rate distribution: by year\n');
format = '%2.0f\t %2.0f\t %2.0f\t %2.0f\t %2.0f\t %2.0f\t %2.0f\n';
fprintf(1,format,pctiles);
heat_format = '%5.0f\t %5.0f\t %5.0f\t %5.0f\t %5.0f\t %5.0f\t %5.0f\n';
for i = 1:length(auction_years);
    fprintf(1,heat_format,heat_pctiles(i,:));
end

% For delta
delta_pctiles = zeros(length(auction_years),length(pctiles));
for i = 1:length(auction_years)
    delta_pctiles(i,:) = prctile(obj.bids.Delta(obj.bids.auction_year==...
        auction_years(i)),pctiles);
end

fprintf(1,'\nPercentiles of delta distribution: by year\n');
fprintf(1,format,pctiles);
delta_format = '%5.2f\t %5.2f\t %5.2f\t %5.2f\t %5.2f\t %5.2f\t %5.2f\n';
for i = 1:length(auction_years);
    fprintf(1,delta_format,delta_pctiles(i,:));
end

% Percentiles of type distribution across fuel types

% For heat
fuel_sources = unique(obj.bids.source);
heat_pctiles = zeros(length(fuel_sources),length(pctiles));
for i = 1:length(fuel_sources)
    heat_pctiles(i,:) = prctile(obj.bids.h(obj.bids.source==...
        fuel_sources(i)),pctiles);
end

fprintf(1,'\nPercentiles of heat rate distribution: by fuel source\n');
fprintf(1,format,pctiles);
for i = 1:length(fuel_sources);
    fprintf(1,heat_format,heat_pctiles(i,:));
end

% For delta
delta_pctiles = zeros(length(fuel_sources),length(pctiles));
for i = 1:length(fuel_sources)
    delta_pctiles(i,:) = prctile(obj.bids.Delta(obj.bids.source==...
        fuel_sources(i)),pctiles);
end

fprintf(1,'\nPercentiles of delta distribution: by fuel source\n');
fprintf(1,format,pctiles);
for i = 1:length(fuel_sources);
    fprintf(1,delta_format,delta_pctiles(i,:));
end

    
end

