function [ ] = fitBidRegressions( bids )
%fitBidRegressions Fit linear regressions for mean bids
%  
% INPUT:
%   bids - Data table of levelised tariffs and bid characteristics
%
% OUTPUT:
%   display regression results to screen

%% New variables for regression

% Year effects
bids.year2006 = double(bids.auction_year == 2006);
bids.year2007 = double(bids.auction_year == 2007);
bids.year2008 = double(bids.auction_year == 2008);
bids.year2009 = double(bids.auction_year == 2009);
bids.year2010 = double(bids.auction_year == 2010);
bids.year2011 = double(bids.auction_year == 2011);
bids.year2012 = double(bids.auction_year == 2012);

% Linear years
bids.yearsFrom2006 = bids.auction_year - 2006;

%% Final linear model of mean scores
lm1 = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_imported + coal_domestic + priceXnotcaptive']);
display(lm1);

lm1b = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_imported + coal_domestic + priceXnotcaptive + ', ...
                  'priceXcaptive']);
display(lm1b);

lm1b = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_imported + coal_domestic + priceXnotcaptive + ', ...
                  'priceXcaptive']);
display(lm1b);

lm1c = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_imported + coal_domestic + price']);
display(lm1c);

lm1d = fitlm(bids,['LevelisedTariff ~ bidders + UMPP + ', ...
                  'coal_imported + coal_domestic + price']);
display(lm1d);

lm1e = fitlm(bids,['LevelisedTariff ~ bidders + winners + UMPP + ', ...
                  'coal_imported + coal_domestic + price']);
display(lm1e);

lm1f = fitlm(bids,['LevelisedTariff ~ bidders_per_winner + UMPP + ', ...
                  'coal_imported + coal_domestic + price']);
display(lm1f);

lm2 = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_notcaptive + priceXnotcaptive']);
display(lm2);
scatter(bids.auction_year,lm2.Residuals.Raw);

% lm4 = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
%                   'coal_notcaptive + priceXcaptive + priceXnotcaptive']);
% display(lm4);

% lm6 = fitlm(bids,['LevelisedTariff ~ bidders_top + priceXnotcaptive +' ...
%                   'coal_notcaptive + case2exUMPP + UMPPXnotcaptive +' ...
%                   'anpara']);
% display(lm6);

lm2b = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_notcaptive + priceXnotcaptive + yearsFrom2006']);
display(lm2b);

lm2c = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_notcaptive + priceXnotcaptive + year2012']);
display(lm2c);

%% Investigation of the determinants of scores


lm7 = fitlm(bids,['LevelisedTariff ~ year2006 + year2007 + year2008 +' ...
                  'year2009 + year2010 + year2011 + year2012'],...
                  'Intercept',false);
display(lm7);

lm7b = fitlm(bids,['LevelisedTariff ~ year2006 + year2007 + year2008 +' ...
                  'year2009 + year2010 + year2011 + year2012 +' ...
                  'coal_notcaptive'],...
                  'Intercept',false);
display(lm7b);

% Look at coal price effects
lm8 = fitlm(bids,['LevelisedTariff ~ trailing_price']);
display(lm8);
 
lm8b = fitlm(bids,['LevelisedTariff ~ trailing_price + variance_price +' ...
                  'expected_price']);
display(lm8b);

lm8c = fitlm(bids,['LevelisedTariff ~ bidders_top + trailing_price +' ...
                  'coal_notcaptive + case2exUMPP + UMPPXnotcaptive']);
display(lm8c);

% Look at state effects
lm9 = fitlm(bids,['LevelisedTariff ~ bidders_top + case2 + UMPP + ', ...
                  'coal_notcaptive + priceXnotcaptive + ', ...
                  'state_AP + state_BH + state_GJ + state_KA + ' ...
                  'state_MH + state_MP + state_PB + state_RJ + ' ...
                  'state_UP']);
display(lm9);              

%% Summarize bid components over time
bids = bids(bids.clean,:);

gs = grpstats( bids,'auction_year', {'mean'}, ...
               'datavars', {'capacity','energy_nesc','energy_esc','transport'});
display(gs);

gs1 = grpstats( bids,'auction_year', {'std'}, ...
               'datavars', {'capacity','energy_nesc','energy_esc','transport'});
display(gs1);

gs2 = grpstats( bids,'auction_year', {'numel','mean','median','min','max'}, ...
               'datavars', {'capacity'});
display(gs2);

gs3 = grpstats( bids,'UMPP', {'numel','mean','median','min','max'}, ...
               'datavars', {'capacity'});
display(gs3);

% Regress bid components on project type and year
lm7b = fitlm(bids,['capacity ~ year2006 + year2007 + year2008 +' ...
                  'year2009 + year2010 + year2012 +' ...
                  'coal_notcaptive + UMPP'],...
                  'Intercept',false);
display(lm7b);

lm7b = fitlm(bids,['energy_nesc ~ year2006 + year2007 + year2008 +' ...
                  'year2009 + year2010 + year2012 +' ...
                  'coal_notcaptive + UMPP'],...
                  'Intercept',false);
display(lm7b);

lm7b = fitlm(bids,['energy_esc ~ year2006 + year2007 + year2008 +' ...
                  'year2009 + year2010 + year2012 +' ...
                  'coal_notcaptive + UMPP'],...
                  'Intercept',false);
display(lm7b);

lm7b = fitlm(bids,['transport ~ year2006 + year2007 + year2008 +' ...
                  'year2009 + year2010 + year2012 +' ...
                  'coal_notcaptive + UMPP'],...
                  'Intercept',false);
display(lm7b);

%% Look at changes in capacity charge distribution

% Linear trend of capacity charge
lm7c = fitlm(bids,['capacity ~ yearsFrom2006'],'Intercept',true);
display(lm7c);

% Percentiles of capacity charge
auction_years = unique(bids.auction_year);
pctiles = [ 5 10 15 20 25 50 75 90 ];
capacity_pctiles = zeros(length(auction_years),length(pctiles));
for i = 1:length(auction_years)
    capacity_pctiles(i,:) = prctile(bids.capacity(bids.auction_year==...
        auction_years(i)),pctiles);
end
display(capacity_pctiles);

% Figures of capacity histograms
figure;
for i = 1:length(auction_years)
    subplot(length(auction_years),1,i);
    hist(bids.capacity(bids.auction_year==auction_years(i)));
    xlim([0 2.6]);
    title(sprintf('Year %4.0f',auction_years(i)));
end

end
