%% Initialize variables.
filename = '/Users/ryotamaki/Dropbox/case1bidding/data/external/coal_price_newcastle.csv';
delimiter = ',';

%% Read columns of data as text:
% For more information, see the TEXTSCAN documentation.
formatSpec = '%s%s%s%[^\n\r]';

%% Open the text file.
fileID = fopen(filename,'r');

%% Read columns of data according to the format.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'TextType', 'string',  'ReturnOnError', false);

%% Close the text file.
fclose(fileID);

%% Convert the contents of columns containing numeric text to numbers.
% Replace non-numeric text with NaN.
raw = repmat({''},length(dataArray{1}),length(dataArray)-1);
for col=1:length(dataArray)-1
    raw(1:length(dataArray{col}),col) = mat2cell(dataArray{col}, ones(length(dataArray{col}), 1));
end
numericData = NaN(size(dataArray{1},1),size(dataArray,2));

for col=[2,3]
    % Converts text in the input cell array to numbers. Replaced non-numeric
    % text with NaN.
    rawData = dataArray{col};
    for row=1:size(rawData, 1)
        % Create a regular expression to detect and remove non-numeric prefixes and
        % suffixes.
        regexstr = '(?<prefix>.*?)(?<numbers>([-]*(\d+[\,]*)+[\.]{0,1}\d*[eEdD]{0,1}[-+]*\d*[i]{0,1})|([-]*(\d+[\,]*)*[\.]{1,1}\d+[eEdD]{0,1}[-+]*\d*[i]{0,1}))(?<suffix>.*)';
        try
            result = regexp(rawData(row), regexstr, 'names');
            numbers = result.numbers;
            
            % Detected commas in non-thousand locations.
            invalidThousandsSeparator = false;
            if numbers.contains(',')
                thousandsRegExp = '^\d+?(\,\d{3})*\.{0,1}\d*$';
                if isempty(regexp(numbers, thousandsRegExp, 'once'))
                    numbers = NaN;
                    invalidThousandsSeparator = true;
                end
            end
            % Convert numeric text to numbers.
            if ~invalidThousandsSeparator
                numbers = textscan(char(strrep(numbers, ',', '')), '%f');
                numericData(row, col) = numbers{1};
                raw{row, col} = numbers{1};
            end
        catch
            raw{row, col} = rawData{row};
        end
    end
end


%% Split data into numeric and string columns.
rawNumericColumns = raw(:, [2,3]);
rawStringColumns = string(raw(:, 1));


%% Replace non-numeric cells with NaN
R = cellfun(@(x) ~isnumeric(x) && ~islogical(x),rawNumericColumns); % Find non-numeric cells
rawNumericColumns(R) = {NaN}; % Replace non-numeric cells

%% Create output variable
coalpricenewcastle = table;
coalpricenewcastle.Month = rawStringColumns(:, 1);
coalpricenewcastle.Price = cell2mat(rawNumericColumns(:, 1));
coalpricenewcastle.Change = cell2mat(rawNumericColumns(:, 2));

%% Clear temporary variables
clearvars filename delimiter formatSpec fileID dataArray ans raw col numericData rawData row regexstr result numbers invalidThousandsSeparator thousandsRegExp rawNumericColumns rawStringColumns R;

%% Store number of rows in table, used for row offset calculations
nrow = size(coalpricenewcastle,1)
%% Generate lagged_price column
coalpricenewcastle.lagged_price = zeros(nrow,1)
%% Copy over offset prices into lagged_price column
coalpricenewcastle.lagged_price(62:end) = coalpricenewcastle.Price(2:end-60) 
%% Generate pricediv column
coalpricenewcastle.pricediv = zeros(nrow,1)
%% Element-wise division to compute pricediv values
coalpricenewcastle.pricediv = coalpricenewcastle.Price./coalpricenewcastle.lagged_price
%% Store row containing the relevant pricediv elements
x = coalpricenewcastle.pricediv(62:end)
%% Log prices
log_price = log(x)
%% Histfit Overlay
%%histfit(x,30,'lognormal')
%% Parameter Estiamtes via MLE
[parmhat,parmhatci] = lognfit(x)
BIN_WIDTH = 0.2
BIN_MAX = 8 
BIN_RANGE = BIN_WIDTH:BIN_WIDTH:BIN_MAX

% 99%CI about mean parmhatci(:,1)
% 99%CI about stdev parmhatci(:,2)

figure1 = figure('Color',[1,1,1])
hold on
h1 = histogram(x,BIN_RANGE)
h1.FaceColor = 'k'
ylim([0,100])

xt = (BIN_RANGE)
y_probability = BIN_WIDTH*lognpdf(xt,parmhat(1),parmhat(2))
y_count = size(x,1)*y_probability

plot(xt,y_count,'k')
xlabel('log(Price/60-month Lagged Price)')% x-axis label
ylabel('Frequency')

dim = [0.3 0.38 0.3 0.3];
str0 = '\mu = ' 
str1 = string(parmhat(1))
str15 = '; '
str3 = ' \sigma = '
str4 = string(parmhat(2))
str = strcat(str0,str1,str15, str3,str4)
str = string(str)
annotation('textbox',dim,'String',str,'FitBoxToText','on');

dim = [0.3 0.3 0.3 0.3];
str0 = '\mu 99% CI: [' 
str1 = string(parmhatci(1,1))
str15 = ','
str2 = string(parmhatci(2,1))
str3 = ']; \sigma 99% CI: [' 
str4 = string(parmhatci(1,2))
str45 = ','
str5 = string(parmhatci(2,2))
str6 = ']'
str = strcat(str0,str1,str15,str2, str3,str4, str45,str5,str6)
str = string(str)
annotation('textbox',dim,'String',str,'FitBoxToText','on');


cd '/Users/ryotamaki/Dropbox/case1bidding/docs/exhibits/figures'

export_fig fig_log_normal_lagged60.pdf

cd '/Users/ryotamaki/Dropbox/case1bidding/code/matlab'


%% 12-month lagged

nrow = size(coalpricenewcastle,1)
% Generate lagged_price column
coalpricenewcastle.lagged_price12 = zeros(nrow,1)
% Copy over offset prices into lagged_price column
coalpricenewcastle.lagged_price12(14:end) = coalpricenewcastle.Price(2:end-12) 
% Generate pricediv column
coalpricenewcastle.pricediv12 = zeros(nrow,1)
% Element-wise division to compute pricediv values
coalpricenewcastle.pricediv12 = coalpricenewcastle.Price./coalpricenewcastle.lagged_price12
% Store row containing the relevant pricediv elements
x12 = coalpricenewcastle.pricediv12(62:end)
% Log prices
log_price = log(x12)
% Histfit Overlay
%%histfit(x,30,'lognormal')
% Parameter Estiamtes via MLE
[parmhat12,parmhatci12] = lognfit(x12)
BIN_WIDTH = 0.2
BIN_MAX = 8 
BIN_RANGE = BIN_WIDTH:BIN_WIDTH:BIN_MAX

% 99%CI about mean parmhatci(:,1)
% 99%CI about stdev parmhatci(:,2)

figure2 = figure('Color',[1,1,1])

hold on

h2 = histogram(x12,BIN_RANGE)
h2.FaceColor = 'k'
ylim([0,130])
xt12 = (BIN_RANGE)
y_probability12 = BIN_WIDTH*lognpdf(xt12,parmhat12(1),parmhat12(2))
y_count12 = size(x12,1)*y_probability12

plot(xt12,y_count12,'k')
xlabel('log(Price/12-month Lagged Price)')% x-axis label
ylabel('Frequency')


dim = [0.3 0.38 0.3 0.3];
str0 = '\mu = ' 
str1 = string(parmhat12(1))
str15 = '; '
str3 = ' \sigma = '
str4 = string(parmhat12(2))
str = strcat(str0,str1,str15, str3,str4)
str = string(str)
annotation('textbox',dim,'String',str,'FitBoxToText','on');

dim = [0.3 0.3 0.3 0.3];
str0 = '\mu 99% CI: [' 
str1 = string(parmhatci12(1,1))
str15 = ','
str2 = string(parmhatci12(2,1))
str3 = ']; \sigma 99% CI: ['
str4 = string(parmhatci12(1,2))
str45 = ','
str5 = string(parmhatci12(2,2))
str6 = ']'
str = strcat(str0,str1,str15,str2, str3,str4, str45,str5,str6)
str = string(str)
annotation('textbox',dim,'String',str,'FitBoxToText','on');

cd '/Users/ryotamaki/Dropbox/case1bidding/docs/exhibits/figures'

export_fig fig_log_normal_lagged12.pdf

cd '/Users/ryotamaki/Dropbox/case1bidding/code/matlab'
