function [ ] = runRobustnessChecks( scenarios, scoreDist, coal, ...
                                        esc_factors, databids, datawork )
% Table of bidder types with alternative values of calibrated parameters
%
%   scenarios : alternative values of parameters under which the estimates
%               have been run
%   scoreDist : estimated distribution of equilibrium scores
%   coal      : coalData object with price series and parameters of the
%               distributions of coal prices
%   esc_factors : escalation factors for coal prices

for i = 2:size(scenarios,1)
    fprintf(1,'Estimating types with the following parameters\n');
    fprintf(1,'\t\teta = %3.2f\tV0 = %3.2f\n\n',scenarios.eta(i),...
                scenarios.V0(i));

   % Initialize type model object
   cd(databids);
   typeDist = typeModel( scoreDist, coal, esc_factors );
   typeDist.noisy = 0;
   
   % Assign parameters to type model object
   typeDist.eta = scenarios.eta(i);
   typeDist.V0  = scenarios.V0(i);
   
   % Run equilrium and counterfactual outcomes once   
   typeDist = typeDist.estimate( coal );
   typeDist = typeDist.counterfactual();
   
   % Bootstrap equilibrium and counterfactual outcomes
   typeDist = typeDist.equilibrium_bootstrap( scoreDist, coal );
   typeDist = typeDist.counterfactual_bootstrap( );
   
   % Save type distribution object
   cd(datawork);
   filename = sprintf('type_model_bootstrap_eta%03.0f_V0%03.0f',...
                       typeDist.eta*100,typeDist.V0*100);
   save(filename,'typeDist');    
    
end

end               
                
