function [ ] = plotIdentification( fid, beta_C, value, beta_C_opt, k_opt )
% plotEnergyAndProfitGrowth  Plot aggregate residual demand and smoothed version
%   along with cleared cournot solution.
% fid       : filename in which to print or 1 to indicate print to screen
% data      : matrix of percent change in Energy use (column 1) and in
%             profit (column 2) in short, medium and long term.  

%% Formatting options
textProp = {'fontsize'    , 14, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 10, ...
            'FontName'    , textProp{4}};
        
textProp = {'fontsize'    , 18, ...
            'FontName'    , 'Times New Roman'};
labProp  = {'fontsize'    , 18, ...
            'FontName'    , textProp{4}};

v_max = zeros(3,1);
i_max = zeros(3,1);
        
%% Plot supply, demand and the clearing price

% Panel 1 : Single profit function with maximum point
plot(beta_C(:,1),value(:,1), ...
    'LineWidth',2,'Color',[0.8 0.8 0.8]);
hold on;

[ v_max(1), i_max(1) ] = max(value(:,1));
plot(beta_C(i_max(1),1),v_max(1),'or','MarkerSize',15)

% Formatting options to apply to all panels
set(gcf, 'Color'       , 'w' );
set(gca, textProp{:}, ...
         'Box'         , 'off'              , ...
         'XTick'       , 0:0.1:0.7, ...
         'LineWidth'   , 1.5 );  
    
% Axis labels
xlabel('Indexation \beta_c'  ,textProp{:})
ylabel('Pseudo-type k(\theta)',textProp{:})

% Axis limits
xlim([0 0.7]);
ylim([-2 -0.5]);

file = sprintf(fid,1);
fprintf(1,'Writing %s to file.\n',file);
export_fig(file,'-painters','-m2');


% Panel 2 : Single profit function with maximum point
plot(beta_C(:,2),value(:,2), ...
    'LineWidth',2,'Color',[0.8 0.8 0.8]);

[ v_max(2), i_max(2) ] = max(value(:,2));
plot(beta_C(i_max(2),2),v_max(2),'or','MarkerSize',15)

file = sprintf(fid,2);
fprintf(1,'Writing %s to file.\n',file);
export_fig(file,'-painters','-m2');


% Panel 3 : Single profit function with maximum point
plot(beta_C(:,3),value(:,3), ...
    'LineWidth',2,'Color',[0.8 0.8 0.8]);

[ v_max(3), i_max(3) ] = max(value(:,3));
plot(beta_C(i_max(3),3),v_max(3),'or','MarkerSize',15)

file = sprintf(fid,3);
fprintf(1,'Writing %s to file.\n',file);
export_fig(file,'-painters','-m2');


% Panel 4 : Add iso-bonus line
plot(beta_C_opt(:,1),-k_opt(:,1),'k-','LineWidth',3);
text(0.48,-1.75,'Iso-bonus locus',labProp{:});

file = sprintf(fid,4);
fprintf(1,'Writing %s to file.\n',file);
export_fig(file,'-painters','-m2');


% Panel 5 : Add iso-cost line
plot(beta_C_opt(:,2),-k_opt(:,2),'r--','LineWidth',3);
text(0.25,-0.70,'Iso-cost locus',labProp{:});

file = sprintf(fid,5);
fprintf(1,'Writing %s to file.\n',file);
export_fig(file,'-painters','-m2');

hold off;


end