function [ f ] = pseudotypeIndexationDistance( theta, k, beta_h, F, ...
                                         beta_e, eta, V0, mu_p, sig_p, EP, VP )
% objective Solve pseudo-type and indexation system for 2-D types
%   Specify a system of equations consisting of the level of the
%   pseudo-type and the optimal level of indexation

% Unknown types
h     = theta(1);
Delta = theta(2);

% Expected value of renegotiation as a function of h
p_bar = (V0 + beta_e) / (h - beta_h); 
ER    = logncdf(p_bar,mu_p,sig_p,'upper');

% Derivative of expectation with respect to beta_h
dERdBetah = - lognpdf(p_bar,mu_p,sig_p) * ...
              (V0 + beta_e) / (h - beta_h)^2;
                                      
% Two equations of
%   (1) Level of pseudo-type
%   (2) FOC for optimal indexation decision

% termsk = [ k beta_h*(EP-P0) -F -h*EP Delta*ER -eta*(h-beta_h)^2*VP ];
% display(termsk);
keq = k - ( -F -h*EP + Delta*ER - eta*(h-beta_h)^2*VP);

% termsh = [ (EP-P0) Delta*dERdBetah eta*2*(h-beta_h)*VP ];
% display(termsh);
heq = Delta*dERdBetah + eta*2*(h-beta_h)*VP;

% Calculate objective function value
g = [ keq; 1e4*heq ];
f = g'*g;

end
